@@ -1,4 +1,4 @@
-/* $Id: gdict-about.c,v 1.6 2001/12/07 18:19:41 seth Exp $ */
+/* $Id: gdict-about.c,v 1.7 2002/02/03 22:22:55 chyla Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -36,7 +36,7 @@ static GtkWidget *gdict_about_new (void)
 	    NULL
     };
     /* Translator credits */
-    gchar *translator_credits = _("");
+    gchar *translator_credits = _("translator_credits");
     GtkWidget *about;
     
     about = gnome_about_new ("GNOME Dictionary", VERSION,
@@ -46,7 +46,7 @@ static GtkWidget *gdict_about_new (void)
 			    "http://www.psilord.com/code/"),
 			     (const char **)authors,
 			     (const char **)documenters,
-			     (const char *)translator_credits,
+			     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
                              NULL);
     gtk_window_set_modal (GTK_WINDOW (about), TRUE);
     return about;
