@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.29 2001/12/07 18:19:41 seth Exp $ */
+/* $Id: gdict-app.c,v 1.33 2002/02/02 21:32:31 kevinv Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -66,12 +66,12 @@ socket_dialog_close_cb (GtkWidget *widget, gpointer data)
 static void
 socket_error_cb (GtkWidget *widget, gchar *message, gpointer data) 
 {
-    if (!socket_error_dialog) {
-        socket_error_dialog = 
-            gnome_error_dialog_parented (message, GTK_WINDOW (gdict_app));
-        gtk_signal_connect (GTK_OBJECT (socket_error_dialog), "close",
-                            GTK_SIGNAL_FUNC (socket_dialog_close_cb), NULL);
-    }
+    socket_error_dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+                                  		  GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                  		  "%s", message, NULL); 
+    gtk_dialog_run (GTK_DIALOG (socket_error_dialog));
+    gtk_widget_destroy (socket_error_dialog);
+    
 }
 
 /* gdict_init_context
@@ -161,10 +161,10 @@ gdict_open_speller (void)
                             GTK_SIGNAL_FUNC (socket_error_cb), NULL);
         gtk_signal_connect (GTK_OBJECT (speller), "close",
                             GTK_SIGNAL_FUNC (spell_close_cb), NULL);
+        gtk_widget_show_all (GTK_WIDGET (speller));
     }
-    
-    if (!GTK_WIDGET_VISIBLE (GTK_WIDGET (speller)))
-    	gtk_widget_show (GTK_WIDGET (speller));
+    else
+    	gtk_window_present (GTK_WINDOW (speller));
 }
 
 
@@ -436,13 +436,6 @@ find_again_cb (GtkMenuItem *menuitem, gpointer user_data)
         gdict_defbox_find (defbox, find_text, FALSE);
 }
 
-static gint
-pref_dialog_close_cb (GtkWidget *widget, gpointer user_data) 
-{
-    pref_dialog = NULL;
-    return FALSE;
-}
-
 static void
 pref_dialog_apply_cb (GtkWidget *widget, gpointer user_data) 
 {
@@ -456,27 +449,25 @@ gdict_not_online ()
     GtkWidget *w;
     gchar *s;
     
-    s = g_strdup_printf (_("Unable to perform requested operation, either because the server\n"
-			   "you are using is down or because you are not connected to the\n"
-			   "Internet. If you are not already connected to the Internet, please\n" 
-    			   "do so and try again."));
-    w = gnome_error_dialog (s);
-    gnome_dialog_run_and_close (GNOME_DIALOG (w));
+    s = g_strdup_printf (_("Unable to perform requested operation. \n"
+    		           "Either the server you are using is not available \n"
+    		           "or you are not connected to the Internet."));
+    w = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+                                     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                     "%s", s, NULL); 
+    gtk_dialog_run (GTK_DIALOG (w));
+    gtk_widget_destroy (w);
     g_free (s);
 }
 
 void
 gdict_app_show_preferences (void) 
 {
+	
     if (!pref_dialog) {
+    g_print ("show prefs \n");
         pref_dialog = gdict_pref_dialog_new (context);
-        gtk_signal_connect (GTK_OBJECT (pref_dialog), "apply_changes",
-                            GTK_SIGNAL_FUNC (pref_dialog_apply_cb), NULL);
-        gtk_signal_connect (GTK_OBJECT (pref_dialog), "socket_error",
-                            GTK_SIGNAL_FUNC (socket_error_cb), NULL);
-        gtk_signal_connect (GTK_OBJECT (pref_dialog), "close",
-                            GTK_SIGNAL_FUNC (pref_dialog_close_cb),
-			    NULL);
+        
     }
 
     gtk_widget_show (pref_dialog);
@@ -551,30 +542,6 @@ static GnomeUIInfo menubar_uiinfo[] = {
     GNOMEUIINFO_END
 };
 
-static GnomeUIInfo toolbar_uiinfo[] = {
-    GNOMEUIINFO_ITEM_STOCK (N_("Lookup"), 
-			    N_("Lookup word in dictionary"), 
-			    lookup_cb, GNOME_STOCK_PIXMAP_SEARCH),
-    GNOMEUIINFO_ITEM_STOCK (N_("Spell"), 
-			    N_("Check word spelling"), 
-			    spell_cb, GNOME_STOCK_PIXMAP_SPELLCHECK),
-    GNOMEUIINFO_SEPARATOR,
-    GNOMEUIINFO_ITEM_STOCK (N_("Cut"), 
-			    N_("Cut to Clipboard"), 
-			    cut_cb, GNOME_STOCK_PIXMAP_CUT),
-    GNOMEUIINFO_ITEM_STOCK (N_("Copy"), 
-			    N_("Copy to Clipboard"), 
-			    copy_cb, GNOME_STOCK_PIXMAP_COPY),
-    GNOMEUIINFO_ITEM_STOCK (N_("Paste"), 
-			    N_("Paste Clipboard Contents"), 
-			    paste_cb, GNOME_STOCK_PIXMAP_PASTE),
-    GNOMEUIINFO_SEPARATOR,
-    GNOMEUIINFO_ITEM_STOCK (N_("Settings"), 
-			  N_("Server to use, default search strategy, fonts"), 
-			    preferences_cb, GNOME_STOCK_PIXMAP_PREFERENCES),
-    GNOMEUIINFO_END
-};
-
 enum
 {
   TARGET_STRING,
@@ -614,7 +581,6 @@ GtkWidget *gdict_app_create (gboolean applet) {
 		&applet_close_item, sizeof(GnomeUIInfo));
 
     gnome_app_create_menus (GNOME_APP (gdict_app), menubar_uiinfo);
-    gnome_app_create_toolbar (GNOME_APP (gdict_app), toolbar_uiinfo);
     
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
@@ -625,14 +591,18 @@ GtkWidget *gdict_app_create (gboolean applet) {
     gtk_widget_show (hbox);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     
-    label = gtk_label_new_with_mnemonic (_("_Lookup"));
+    label = gtk_label_new (_("Word : "));
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    
+    label = gtk_label_new_with_mnemonic (_("_Look Up"));
     gtk_widget_show (label);
     gtk_misc_set_padding (GTK_MISC (label), 2, 1);
     
     button = gtk_button_new ();
     gtk_container_add (GTK_CONTAINER (button), label);
     gtk_widget_show (button);
-    gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+    gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, FALSE, 0);
     gtk_drag_dest_set (button, GTK_DEST_DEFAULT_ALL, drop_targets, 
     		       G_N_ELEMENTS (drop_targets), GDK_ACTION_COPY | GDK_ACTION_MOVE);
     g_signal_connect (G_OBJECT (button), "clicked",
@@ -640,9 +610,8 @@ GtkWidget *gdict_app_create (gboolean applet) {
     g_signal_connect (G_OBJECT (button), "drag_data_received",
     		      G_CALLBACK (lookup_button_drag_cb), defbox);
 
-    gnome_word_entry = gnome_entry_new ("Word entry");
+    gnome_word_entry = gnome_entry_new ("Wordentry");
     gtk_widget_show (gnome_word_entry);
-    /*gtk_box_pack_start (GTK_BOX (vbox), gnome_word_entry, FALSE, FALSE, 0);*/
     gtk_box_pack_start (GTK_BOX (hbox), gnome_word_entry, TRUE, TRUE, 0);
     GTK_WIDGET_SET_FLAGS (gnome_word_entry, GTK_CAN_FOCUS);
     gtk_widget_grab_focus (gnome_word_entry);
