@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.28 2002/04/26 21:32:34 gman Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.19 2002/02/02 21:32:31 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -47,12 +47,6 @@ static gchar *typeface_sel_names[NUM_TYPEFACES] = {
 #define NUM_TYPEFACE_ROWS 4
 #define NUM_TYPEFACE_COLS 2
 
-GtkWidget *db_label, *strat_label;
-GtkWidget *error_label1 = NULL;
-GtkWidget *error_label2 = NULL;
-GtkWidget *alignment1 = NULL;
-GtkWidget *alignment2 = NULL;
-
 static gint gdict_pref_dialog_signals[LAST_SIGNAL] = { 0 };
 extern GConfClient *client;
 
@@ -84,10 +78,8 @@ static void pref_dialog_ok_cb       (GtkWidget *widget, gpointer data);
 static void pref_dialog_apply_cb    (GtkWidget *widget, gpointer data);
 static void pref_dialog_close_cb    (GtkWidget *widget, gpointer data);
 static void response_cb		    (GtkDialog *dialog, gint response);
-static gboolean	set_server_cb 	    (GtkWidget *widget, GdkEventFocus *event, gpointer data);
-static gboolean set_port_cb	    (GtkWidget *widget, GdkEventFocus *event, gpointer data);
-static void set_default_server      (GtkButton *button, gpointer data);
-static void set_default_port        (GtkButton *button, gpointer data);
+static void server_button_cb	    (GtkButton *button, gpointer data);
+static void port_button_cb	    (GtkButton *button, gpointer data);
 static void smart_lookup_cb	    (GtkToggleButton *toggle, gpointer data);
 
 /* gdict_pref_dialog_get_type
@@ -173,7 +165,7 @@ gdict_pref_dialog_class_init (GDictPrefDialogClass *class)
 static void
 create_dialog (GDictPrefDialog *pref_dialog)
 {
-    GtkWidget *server_label, *port_label, *alignment;
+    GtkWidget *label, *alignment;
     GtkWidget *vbox, *table;
     GtkWidget *button;    
     gchar *port_str;
@@ -182,7 +174,7 @@ create_dialog (GDictPrefDialog *pref_dialog)
     pref_dialog->database = gdict_pref.database;
     pref_dialog->dfl_strat = gdict_pref.dfl_strat;
     
-    gtk_window_set_title (GTK_WINDOW (pref_dialog), _("Dictionary Preferences"));
+    gtk_window_set_title (GTK_WINDOW (pref_dialog), _("Preferences"));
     gtk_window_set_policy (GTK_WINDOW (pref_dialog), FALSE, FALSE, FALSE);    
     vbox = GTK_DIALOG (pref_dialog)->vbox;
 
@@ -194,7 +186,7 @@ create_dialog (GDictPrefDialog *pref_dialog)
     gtk_table_set_col_spacings (pref_dialog->table, 6);
 
     pref_dialog->smart_lookup_btn = 
-        GTK_CHECK_BUTTON (gtk_check_button_new_with_mnemonic (_("Smart _lookup")));
+        GTK_CHECK_BUTTON (gtk_check_button_new_with_label (_("Smart lookup")));
     g_signal_connect (G_OBJECT (pref_dialog->smart_lookup_btn), "toggled",
     		      G_CALLBACK (smart_lookup_cb), pref_dialog);
     gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (pref_dialog->smart_lookup_btn),
@@ -204,67 +196,43 @@ create_dialog (GDictPrefDialog *pref_dialog)
     gtk_table_attach_defaults (pref_dialog->table, 
                                GTK_WIDGET (pref_dialog->server_entry), 
                                1, 2, 0, 1);
-    g_signal_connect (G_OBJECT (pref_dialog->server_entry), "focus_out_event",
-    		      G_CALLBACK (set_server_cb), pref_dialog);
     
-    server_label = gtk_label_new_with_mnemonic (_("_Server:"));
-    gtk_label_set_mnemonic_widget (GTK_LABEL (server_label), 
-    				   GTK_WIDGET (pref_dialog->server_entry));
-    gtk_label_set_justify (GTK_LABEL (server_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (server_label), 1, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, server_label, 0, 1, 0, 1);
+    label = gtk_label_new (_("Server:"));
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 0, 1);
     
-    button = gtk_button_new_with_mnemonic (_("De_fault"));
+    button = gtk_button_new_with_mnemonic (_("Set _Server"));
     gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 0, 1);
     g_signal_connect (G_OBJECT (button), "clicked",
-    		      G_CALLBACK (set_default_server), pref_dialog);
+    		      G_CALLBACK (server_button_cb), pref_dialog);
 
-    if( gail_loaded )
-        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Reset server to default"));
-
-    port_label = gtk_label_new_with_mnemonic (_("_Port:"));
-    gtk_table_attach_defaults (pref_dialog->table, port_label, 0, 1, 1, 2);
-    gtk_label_set_justify (GTK_LABEL (port_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (port_label), 1, 0.5);
+    label = gtk_label_new (_("Port:"));
+    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 1, 2);
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
 
     pref_dialog->port_entry = GTK_ENTRY (gtk_entry_new ());
-    gtk_label_set_mnemonic_widget (GTK_LABEL (port_label), 
-    				   GTK_WIDGET (pref_dialog->port_entry));
     gtk_table_attach_defaults (pref_dialog->table, 
                                GTK_WIDGET (pref_dialog->port_entry), 
                                1, 2, 1, 2);
-    g_signal_connect (G_OBJECT (pref_dialog->port_entry), "focus_out_event",
-    		      G_CALLBACK (set_port_cb), pref_dialog);
                                
-    button = gtk_button_new_with_mnemonic (_("Def_ault"));
+    button = gtk_button_new_with_mnemonic (_("Set _Port"));
     gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 1, 2);
     g_signal_connect (G_OBJECT (button), "clicked",
-    		      G_CALLBACK (set_default_port), pref_dialog);
+    		      G_CALLBACK (port_button_cb), pref_dialog);
     
-    if( gail_loaded )
-    {
-        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Reset port to default"));
-        add_atk_namedesc(server_label, _("Server"), _("Server"));
-        add_atk_namedesc( GTK_WIDGET (pref_dialog->server_entry), _("Server Entry"), _("Enter the Server Name"));
-        add_atk_relation( GTK_WIDGET (pref_dialog->server_entry), server_label, ATK_RELATION_LABELLED_BY);
-
-        add_atk_namedesc(port_label, _("Port"), _("Port"));
-        add_atk_namedesc( GTK_WIDGET(pref_dialog->port_entry), _("Port Entry"), _("Enter the Port Number"));
-        add_atk_relation( GTK_WIDGET(pref_dialog->port_entry), port_label, ATK_RELATION_LABELLED_BY);
-
-    }
-
-    db_label = gtk_label_new_with_mnemonic (_("_Database:"));
-    gtk_label_set_justify (GTK_LABEL (db_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (db_label), 1, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, db_label, 0, 1, 3, 4);
+    label = gtk_label_new (_("Database:"));
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 3, 4);
     pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
     gtk_widget_show (GTK_WIDGET (pref_dialog->db_list));
     
-    strat_label = gtk_label_new_with_mnemonic (_("D_efault strategy:"));
-    gtk_label_set_justify (GTK_LABEL (strat_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (strat_label), 1, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, strat_label, 0, 1, 4, 5);
+    label = gtk_label_new (_("Default strategy:"));
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 4, 5);
     pref_dialog->strat_list = GTK_MENU (gtk_menu_new ());
     gtk_widget_show (GTK_WIDGET (pref_dialog->strat_list));
     
@@ -278,9 +246,8 @@ create_dialog (GDictPrefDialog *pref_dialog)
     g_signal_connect (G_OBJECT (pref_dialog), "response",
     		      G_CALLBACK (response_cb), NULL);
 
-    if (gdict_pref.server != NULL)
-	    gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
-				gdict_pref.server);
+    gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
+			gdict_pref.server);
     port_str = g_strdup_printf("%d", (int) gdict_pref.port);
     gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port_str);
     g_free(port_str);
@@ -381,9 +348,8 @@ pref_dialog_add_db (GDictPrefDialog *pref_dialog, gchar *db,
     gtk_object_set_data (GTK_OBJECT (menu_item), "db_name", db);
     gtk_widget_show (menu_item);
     gtk_menu_append (pref_dialog->db_list, menu_item);
-
-    if ((pref_dialog->database == NULL)
-		    || (!strcmp (pref_dialog->database, db)))
+    
+    if (!strcmp (pref_dialog->database, db))
       gtk_menu_set_active (pref_dialog->db_list, pref_dialog->database_idx);
     pref_dialog->database_idx++;
 }
@@ -406,8 +372,7 @@ pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat,
     gtk_widget_show (menu_item);
     gtk_menu_append (pref_dialog->strat_list, menu_item);
     
-    if ((pref_dialog->dfl_strat == NULL)
-		    || (!strcmp (pref_dialog->dfl_strat, strat)))
+    if (!strcmp (pref_dialog->dfl_strat, strat))
 	gtk_menu_set_active (pref_dialog->strat_list,
 			     pref_dialog->dfl_strat_idx);
     pref_dialog->dfl_strat_idx++;
@@ -441,16 +406,8 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
     pref_dialog->get_db_cmd->status_notify_cb = pref_status_cb;
     pref_dialog->get_db_cmd->user_data = pref_dialog;
     pref_dialog->database_idx = 0;
-
-    if ((alignment1) && (error_label1))
-    {
-	gtk_container_remove (GTK_CONTAINER (alignment1), error_label1);
-	gtk_widget_destroy (GTK_WIDGET (alignment1));
-	error_label1 = NULL;
-	alignment1 = NULL;
-    }
     
-    pref_dialog_add_db (pref_dialog, "*", _("Search all databases"));
+    pref_dialog_add_db (pref_dialog, "!", _("Search all databases"));
  
     if (dict_command_invoke (pref_dialog->get_db_cmd,
 			     pref_dialog->context) == -1)
@@ -458,11 +415,12 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
 	/* Could not look up search strategies, so just display a
 	 * label; FIXME: Memory leak
 	 */
-	error_label1 = GTK_WIDGET (gtk_label_new (_("Cannot connect to server")));
-	alignment1 = GTK_WIDGET (gtk_alignment_new (0, 0.5, 0, 0));
-	gtk_container_add (GTK_CONTAINER (alignment1), error_label1);
-	gtk_table_attach_defaults (pref_dialog->table, alignment1, 1, 2, 3, 4);
-	gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
+	error_label = gtk_label_new (_("Cannot connect to server"));
+        alignment = gtk_alignment_new (0, 0.5, 0, 0);
+        gtk_container_add (GTK_CONTAINER (alignment), 
+                           GTK_WIDGET (error_label));
+        gtk_table_attach_defaults (pref_dialog->table, alignment, 1, 2, 3, 4);
+        gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
     }
 }
 
@@ -494,14 +452,6 @@ pref_dialog_reset_strat (GDictPrefDialog *pref_dialog) {
     pref_dialog->get_strat_cmd->status_notify_cb = pref_status_cb;
     pref_dialog->get_strat_cmd->user_data = pref_dialog;
     pref_dialog->dfl_strat_idx = 0;
-
-    if ((alignment2) && (error_label2))
-    {
-	gtk_container_remove (GTK_CONTAINER (alignment2), error_label2);
-	gtk_widget_destroy (GTK_WIDGET (alignment2));
-	error_label2 = NULL;
-	alignment2 = NULL;
-    }
     
     if (dict_command_invoke (pref_dialog->get_strat_cmd,
 			     pref_dialog->context) == -1) 
@@ -509,11 +459,12 @@ pref_dialog_reset_strat (GDictPrefDialog *pref_dialog) {
 	/* Could not look up search strategies, so just display a
 	 * label; FIXME: Memory leak
 	 */
-	error_label2 = GTK_WIDGET (gtk_label_new (_("Cannot connect to server")));
-	alignment2 = GTK_WIDGET (gtk_alignment_new (0, 0.5, 0, 0));
-	gtk_container_add (GTK_CONTAINER (alignment2), error_label2);
-	gtk_table_attach_defaults (pref_dialog->table, alignment2, 1, 2, 4, 5);
-	gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
+	error_label = gtk_label_new (_("Cannot connect to server"));
+        alignment = gtk_alignment_new (0, 0.5, 0, 0);
+        gtk_container_add (GTK_CONTAINER (alignment), 
+                           GTK_WIDGET (error_label));
+        gtk_table_attach_defaults (pref_dialog->table, alignment, 1, 2, 4, 5);
+        gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
     }
 }
 
@@ -609,29 +560,9 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
         gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
         
         if (command->cmd == C_SHOW_DB)
-        {
 	    pref_dialog->db_sel = option_menu;
-            gtk_label_set_mnemonic_widget (GTK_LABEL (db_label), GTK_WIDGET (pref_dialog->db_sel));
-
-            if ( gail_loaded)
-            {
-                add_atk_namedesc(db_label, _("Database"), _("Database Name"));
-                add_atk_relation( GTK_WIDGET (option_menu), db_label, ATK_RELATION_LABELLED_BY);
-
-            }
-        }
         else if (command->cmd == C_SHOW_STRAT)
-        {
 	    pref_dialog->strat_sel = option_menu;
-            gtk_label_set_mnemonic_widget (GTK_LABEL (strat_label), GTK_WIDGET (pref_dialog->strat_sel));
-
-            if ( gail_loaded )
-            {
-                add_atk_namedesc(strat_label, _("Default Strategy"), _("Default Strategy"));
-                add_atk_relation( GTK_WIDGET (option_menu), strat_label, ATK_RELATION_LABELLED_BY);
-
-            }
-        }
     }
 }
 
@@ -642,38 +573,58 @@ response_cb (GtkDialog *dialog, gint response)
     
 }
 
-static gboolean
-set_server_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
+static void
+server_button_cb (GtkButton *button, gpointer data)
 {
     GDictPrefDialog *pref_dialog = data;
     gchar *server;
     server = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->server_entry), 0, -1);
 
-    if ((server != NULL)
-		    && ((gdict_pref.server == NULL)
-			    || (strcmp (gdict_pref.server, server)))) {
+    if (strcmp (gdict_pref.server, server)) {
+	gchar *old_server;
 	
-	if (gdict_pref.server)
-		g_free (gdict_pref.server);
+        old_server = gdict_pref.server; 
         gdict_pref.server = g_strdup(server);
-        gdict_init_context ();
-        pref_dialog->context = context;
-        pref_dialog_reset_db (pref_dialog);
-        pref_dialog_reset_strat (pref_dialog);
+       
+        /* Try connecting. If we fail, restore the old config and abort */
+        if (gdict_init_context ()) {
+        	        GtkWidget *dialog;
+        	        
+        	        dialog = gtk_message_dialog_new (NULL,
+        	                                         GTK_DIALOG_DESTROY_WITH_PARENT,
+        	                                         GTK_MESSAGE_ERROR,
+        	                                         GTK_BUTTONS_OK,
+        	                                         "%s",
+        	                                         _("The server you specified could not be found."));
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
+			g_free (gdict_pref.server);
+			gdict_pref.server = old_server;
+			gdict_init_context ();
+			gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
+				            gdict_pref.server);
+			return;
+		}
+	else {
+        
+            pref_dialog->context = context;
+        
+            g_free (old_server);
+            
+            pref_dialog_reset_db (pref_dialog);
+            pref_dialog_reset_strat (pref_dialog);
            
-        gconf_client_set_string (client, "/apps/gdict/server", gdict_pref.server, NULL);
-
+            gconf_client_set_string (client, "/apps/gdict/server", gdict_pref.server, NULL);
+        }
     }
-   
+    
     if (server)
     	g_free (server);
-    	
-    return FALSE;
 }
 
 
-static gboolean 
-set_port_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
+static void 
+port_button_cb (GtkButton *button, gpointer data)
 {
     GDictPrefDialog *pref_dialog = data;
     gchar *port;
@@ -683,46 +634,42 @@ set_port_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
     
     if (gdict_pref.port != atoi (port)) {
     
+        old_port = gdict_pref.port;
         gdict_pref.port = atoi (port);
-        gdict_init_context ();
+        /* Try connecting. If we fail, restore the old config and abort */
+        if (gdict_init_context ()) {
+        	        GtkWidget *dialog;
+        	        gchar *port_str;
+        	        
+        	        dialog = gtk_message_dialog_new (NULL,
+        	                                         GTK_DIALOG_DESTROY_WITH_PARENT,
+        	                                         GTK_MESSAGE_ERROR,
+        	                                         GTK_BUTTONS_OK,
+        	                                         "%s",
+        	                                         _("The server could not be found on that port."));
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
+			g_free (gdict_pref.server);
+			gdict_pref.port = old_port;
+			gdict_init_context ();
+			port_str = g_strdup_printf("%d", (int) gdict_pref.port);
+    			gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port_str);
+    			g_free(port_str);
+			return;
+		}
+	else {
         
-        pref_dialog->context = context;
+            pref_dialog->context = context;
         
-        pref_dialog_reset_db (pref_dialog);
-        pref_dialog_reset_strat (pref_dialog);
+            pref_dialog_reset_db (pref_dialog);
+            pref_dialog_reset_strat (pref_dialog);
             
-        gconf_client_set_int (client, "/apps/gdict/port", gdict_pref.port, NULL);
-       
+            gconf_client_set_int (client, "/apps/gdict/port", gdict_pref.port, NULL);
+        }
     }
     
-    if (port)
-    	g_free (port);
-
-    return FALSE;
-}
-
-static void
-set_default_server (GtkButton *button, gpointer data)
-{
-    GDictPrefDialog *pref_dialog = data;
-    
-    gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry), DICT_DEFAULT_SERVER);
-    set_server_cb (GTK_WIDGET (pref_dialog->port_entry), NULL, data);
-    
-}
-
-static void
-set_default_port (GtkButton *button, gpointer data)
-{
-    GDictPrefDialog *pref_dialog = data;
-    gchar *port;
-    
-    port = g_strdup_printf ("%d", DICT_DEFAULT_PORT);
-    gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port);
     g_free (port);
-    set_port_cb (GTK_WIDGET (pref_dialog->port_entry), NULL, data);
-    
-}    
+}
 
 static void 
 smart_lookup_cb	(GtkToggleButton *toggle, gpointer data)
