@@ -72,7 +72,6 @@ extern UserPrefsStruct *user_prefs;
 
 GdkGC *gc;
 GdkDrawable *canvas;
-PangoLayout *log_layout;
 
 Log *loglist[MAX_NUM_LOGS];
 Log *curlog;
@@ -191,47 +190,28 @@ NumTextLines (int l)
 gboolean
 handle_log_mouse_button (GtkWidget * win, GdkEventButton *event)
 {
+  static guint32 lasttime;
+  static int clicked_before = FALSE;
 
-  if (event->type == GDK_2BUTTON_PRESS) {
-    if (!zoom_visible)
-      create_zoom_view (NULL, NULL);
-  }
-  else if (event->button == 1) {
-    int cursory, nl;
-    Page *np;
-    if (curlog == NULL)
+  if (event->type == GDK_BUTTON_PRESS && !clicked_before)
+    {
+      lasttime = event->time;
+      clicked_before = TRUE;
       return FALSE;
+    }
+  
+  clicked_before = FALSE;
+  if (event->time - lasttime < 100 ||
+      event->time - lasttime > 200)
+    return FALSE;
 
-     cursory = event->y;
-     cursor_visible = TRUE;
-     if ((nl = GetLineAtCursor (cursory)) != -1 && nl != curlog->pointerln)
-     {
-       np = GetPageAtCursor (cursory);
-       log_redrawcursor (curlog->pointerln, nl, np);
-       curlog->pointerln = nl;
-       curlog->pointerpg = np;
-       log_redrawdetail ();
-     }
-  } 
+  /* If zoom is already visible ignore */
+  if (!zoom_visible)
+    create_zoom_view (NULL, NULL);
 
   return FALSE;
 }
 
-gboolean
-handle_log_mouse_scroll (GtkWidget * win, GdkEventScroll *event)
-{
-  GtkAdjustment *adj;
-  adj = GTK_ADJUSTMENT (GTK_RANGE (main_win_scrollbar)->adjustment);
-
-  if (event->direction == GDK_SCROLL_UP)
-    gtk_adjustment_set_value (adj, (adj->value - 5.0));
-  else if (event->direction == GDK_SCROLL_DOWN)
-    gtk_adjustment_set_value (adj, (adj->value + 5.0));
-    
-  return FALSE;
-
-}
-
 /* ----------------------------------------------------------------------
    NAME:        HandleLogKeyboard
    DESCRIPTION: Handle all posible keyboard actions.
@@ -415,27 +395,15 @@ log_repaint (GtkWidget * win, GdkEventExpose * event)
    Page *pg;
    LogLine *line;
    GdkRectangle *area;
-   PangoContext *context;
-   PangoFontMetrics *metrics;
-   PangoFont *font;
 
    if (firsttime)
    {
       if (win == NULL)
 	 return FALSE;
       firsttime = FALSE;
-      log_layout = gtk_widget_create_pango_layout (main_win_scrollbar, "");
-      context = gdk_pango_context_get ();
-      pango_context_set_language (context, gtk_get_default_language ());
-      font = pango_context_load_font (context, cfg->fixedb);
-      metrics = pango_font_get_metrics
-                (font, pango_context_get_language (context));
       canvas = win->window;
       gc = gdk_gc_new (canvas);
-      log_line_sep = PANGO_PIXELS (pango_font_metrics_get_ascent (metrics)) + 3;
-      pango_font_metrics_unref (metrics);
-      g_object_unref (G_OBJECT (context));
-      g_object_unref (G_OBJECT (font));
+      log_line_sep = cfg->fixedb->ascent + 3;
    }
    offset = LOG_TITLEY;
 
@@ -452,10 +420,7 @@ log_repaint (GtkWidget * win, GdkEventExpose * event)
 
    /* Check that there is at least one log */
    if (curlog == NULL)
-   {
-      UpdateStatusArea ();	   
       return FALSE;
-   }
 
    pg = curlog->currentpg;
    ln = curlog->firstline;
@@ -510,11 +475,7 @@ UpdateStatusArea ()
   const char *time_fmt = _("%x"); /* an evil way to avoid warning */
 
   if (curlog == NULL)
-  {
-      gtk_label_set_text (filename_label, "");
-      gtk_label_set_text (date_label, "");    
-      return;
-  }
+    return;
 
   if (curlog->name != NULL)
     {
@@ -604,13 +565,9 @@ DrawLogLine (LogLine *line, int y)
   int num_chars, max_num_chars;
   int col_pos = 0;
   int char_width;
-  PangoRectangle logical_rect;
   
-  pango_layout_set_text (log_layout, "A", 1);
-  pango_layout_set_font_description (log_layout, cfg->fixed);
-  pango_layout_get_pixel_extents (log_layout, NULL, &logical_rect);
-  char_width = logical_rect.width; 
-
+  char_width = gdk_char_width (cfg->fixed, 'A');
+  
   /*gdk_gc_set_foreground (gc, &cfg->white); */
   gdk_gc_set_foreground (gc, &cfg->black);
 
@@ -633,15 +590,12 @@ DrawLogLine (LogLine *line, int y)
   } else {
 	  strcpy (tmp, " ");
   }
-  pango_layout_set_font_description (log_layout, cfg->fixed);
-  pango_layout_set_text (log_layout, tmp, -1);
-  gdk_draw_layout (canvas, gc, LOG_COL1, y-10, log_layout);
+  gdk_draw_string (canvas, cfg->fixedb, gc, LOG_COL1, y, tmp);
 
   /* Print four spaces */
   col_pos = LOG_COL1 + strlen(tmp)*char_width;
   strcpy (tmp, "    ");
-  pango_layout_set_text (log_layout, tmp, -1);
-  gdk_draw_layout (canvas, gc, col_pos, y-10, log_layout);
+  gdk_draw_string (canvas, cfg->fixedb, gc, col_pos, y, tmp);
   col_pos = col_pos + 4*char_width;
 
   strcpy (tmp, " ");
@@ -651,16 +605,12 @@ DrawLogLine (LogLine *line, int y)
   	if (strlen (tmp) > user_prefs->hostname_column_width)
     		tmp[user_prefs->hostname_column_width+1] = '\0';
   }
-  pango_layout_set_text (log_layout, tmp, -1);
-  pango_layout_set_font_description (log_layout, cfg->fixed);
-  gdk_draw_layout (canvas, gc, col_pos, y-10, log_layout);
+  gdk_draw_string (canvas, cfg->fixed, gc, col_pos, y, tmp);
 
   /* Print four spaces */
   col_pos = col_pos + user_prefs->hostname_column_width*char_width;
   strcpy (tmp, "    ");
-  pango_layout_set_text (log_layout, tmp, -1);
-  pango_layout_set_font_description (log_layout, cfg->fixedb);
-  gdk_draw_layout (canvas, gc, col_pos, y-10, log_layout);
+  gdk_draw_string (canvas, cfg->fixedb, gc, col_pos, y, tmp);
   col_pos = col_pos + 4*char_width;
 
   strcpy (tmp, " ");
@@ -670,29 +620,23 @@ DrawLogLine (LogLine *line, int y)
   	if (strlen (tmp) > user_prefs->process_column_width)
     		tmp[user_prefs->process_column_width+1] = '\0';
   }
-  pango_layout_set_text (log_layout, tmp, -1);
-  pango_layout_set_font_description (log_layout, cfg->fixed);
-  gdk_draw_layout (canvas, gc, col_pos, y-10, log_layout);
+  gdk_draw_string (canvas, cfg->fixed, gc, col_pos, y, tmp);
 
   /* Print four spaces */
   col_pos = col_pos + user_prefs->process_column_width*char_width;
   strcpy (tmp, "    ");
-  pango_layout_set_text (log_layout, tmp, -1);
-  pango_layout_set_font_description (log_layout, cfg->fixedb);
-  gdk_draw_layout (canvas, gc, col_pos, y-10, log_layout);
+  gdk_draw_string (canvas, cfg->fixedb, gc, col_pos, y, tmp);
   col_pos = col_pos + 4*char_width;
 
   /* For now max string length is ignored */
   num_chars = MAX (strlen (line->message), 1023);
   tmp[1023] = '\0';
   strncpy (tmp, line->message, 1023);
-  max_num_chars = (canvas_width - 10 - col_pos) / char_width;
+  max_num_chars = (canvas_width - 10 - col_pos) / gdk_char_width (cfg->fixed, 'A');
   if (max_num_chars < num_chars)
     max_num_chars = num_chars;
   tmp[max_num_chars] = '\0';
-  pango_layout_set_text (log_layout, tmp, -1);
-  pango_layout_set_font_description (log_layout, cfg->fixed);
-  gdk_draw_layout (canvas, gc, col_pos, y-10, log_layout);
+  gdk_draw_string (canvas, cfg->fixed, gc, col_pos, y, tmp);
 }
 
 
@@ -707,26 +651,13 @@ DrawMonthHeader (LogLine * line, int y)
    char buf[100];
    int  h, centery, skip;
    GdkColor color[3];
-   PangoContext *context;
-   PangoFontMetrics *metrics;
-   PangoFont *font;
 
    color[0] = cfg->blue1;
    color[1] = cfg->blue;
    color[2] = cfg->blue3;
 
-   context = gdk_pango_context_get ();
-   pango_context_set_language (context, gtk_get_default_language ());
-   font = pango_context_load_font (context, cfg->headingb);
-   metrics = pango_font_get_metrics
-	     (font, pango_context_get_language (context));
-   h = PANGO_PIXELS (pango_font_metrics_get_ascent (metrics)) -
-       PANGO_PIXELS (pango_font_metrics_get_descent (metrics));
-   font = pango_context_load_font (context, cfg->fixed);	
-   metrics = pango_font_get_metrics
-	     (font, pango_context_get_language (context));
-   skip = (log_line_sep - PANGO_PIXELS (pango_font_metrics_get_ascent (metrics))
-	   + PANGO_PIXELS (pango_font_metrics_get_descent (metrics)));
+   h = cfg->headingb->ascent - cfg->headingb->descent;
+   skip = (log_line_sep - cfg->fixed->ascent + cfg->fixed->descent);
    centery = y + log_line_sep - ((2 * log_line_sep - skip - h) >> 1);
    Draw3DBox (canvas, gc, 5, y - log_line_sep + skip , canvas_width - 10, 2*log_line_sep-skip, color);
 
@@ -743,17 +674,9 @@ DrawMonthHeader (LogLine * line, int y)
    } else {
 	   g_snprintf (buf, sizeof (buf), "?%d? %d", (int) line->month, line->date);
    }
-   pango_layout_set_text (log_layout, buf, -1);
-   pango_layout_set_font_description (log_layout, cfg->headingb);
-   gdk_draw_layout (canvas, gc, LOG_COL1 - 1, centery + 1 - 12, log_layout);
+   gdk_draw_string (canvas, cfg->headingb, gc, LOG_COL1 - 1, centery + 1, buf);
    gdk_gc_set_foreground (gc, &cfg->white);
-   pango_layout_set_text (log_layout, buf, -1);
-   pango_layout_set_font_description (log_layout, cfg->headingb);
-   gdk_draw_layout (canvas, gc, LOG_COL1, centery -12, log_layout);
-
-   g_object_unref (G_OBJECT (font));
-   pango_font_metrics_unref (metrics);
-   g_object_unref (G_OBJECT (context));
+   gdk_draw_string (canvas, cfg->headingb, gc, LOG_COL1, centery, buf);
 
 }
 
